@@ -480,6 +480,83 @@ def release(
         click.echo(kacl_changelog_content)
 
 
+@cli.command()
+@click.pass_context
+@click.option(
+    "-m",
+    "--modify",
+    is_flag=True,
+    help="This option will add the changes directly into changelog file.",
+)
+@click.option(
+    "--from-version",
+    required=True,
+    default=None,
+    type=str,
+    help="The version to start squashing from.",
+)
+@click.option(
+    "--to-version",
+    required=False,
+    default=None,
+    type=str,
+    help="The version to squash to. If not given, the latest version will be used.",
+)
+def squash(
+    ctx,
+    modify,
+    from_version,
+    to_version,
+):
+    """Squshes all changes from a given version into a single section. Use '--modify' to directly modify the changelog file."""
+
+    kacl_changelog = load_changelog(ctx)
+
+    if not kacl_changelog.is_valid():
+        click.echo(
+            click.style("Error: ", fg="red")
+            + "Changelog is not valid. Run 'kacl-cli verify' for more information."
+        )
+        sys.exit(1)
+
+    if not to_version:
+        to_version = kacl_changelog.current_version()
+    else:
+        try:
+            to_version = semver.VersionInfo.parse(to_version)
+        except Exception:
+            click.echo(
+                click.style("Error: ", fg="red")
+                + f'"{to_version}" not a valid semantic version.'
+            )
+            sys.exit(1)
+
+    try:
+        from_version = semver.VersionInfo.parse(from_version)
+    except Exception:
+        click.echo(
+            click.style("Error: ", fg="red")
+            + f'"{from_version}" not a valid semantic version.'
+        )
+        sys.exit(1)
+
+    # squash the changes
+    kacl_changelog.squash(
+        version_start=from_version, version_end=to_version, keep_version_info=True
+    )
+
+    # dump the content
+    kacl_changelog_content = kacl.dump(kacl_changelog)
+
+    # check if we should modify the file
+    if modify:
+        with open(kacl_changelog.config.changelog_file_path, "w") as f:
+            f.write(kacl_changelog_content)
+        f.close()
+    else:
+        click.echo(kacl_changelog_content)
+
+
 @cli.command()
 @click.option(
     "-o",
