@@ -2,7 +2,13 @@ import os
 from pathlib import Path
 
 
-def snapshot_directory(snapshot, directory_path, dir_excludes=[".git"], file_excludes=[], sanitize_callbacks={}):
+def snapshot_directory(
+    snapshot,
+    directory_path,
+    dir_excludes=[".git"],
+    file_excludes=[],
+    sanitize_callbacks={},
+):
     snapshot_dir = {}
 
     for root, dirs, files in os.walk(directory_path, topdown=True):
